@@ -228,6 +228,10 @@ def main(
 
         setupField(serveWebsocket=serveWebsocket)
 
+        VortexFactory.setPeerConnectionLimitPerIp(
+            httpServerConfig.concurrentPeerIpConnectionLimit
+        )
+
         setupSite(
             siteName,
             fieldRoot,
